@@ -1,3 +1,13 @@
+try:
+  import cupy as cp
+except ModuleNotFoundError:
+  raise ModuleNotFoundError("cupy is not installed, please visit https://pypi.org/project/cupy/")
+import torch
+import torch.nn as nn
+import numpy as np
+import math
+from time import time
+
 from . import kmeans
 from . import kernels
 
@@ -6,8 +16,3 @@ from .PQ import PQ
 
 from .IVFPQ import IVFPQ
 from .IVFPQR import IVFPQR
-
-try:
-  import cupy
-except ModuleNotFoundError:
-  raise ModuleNotFoundError("cupy is not installed, please visit https://pypi.org/project/cupy/")
\ No newline at end of file
